<?php
##### rrcemeteryedit_ajx.php, installed by ###Admin Cemetery Edit, by Robin Richmond
/* Used to populate a table of Placenames that are candidates for the "Associated Placename"
value in a Cemetery record.
It is called from the Cemetery Edit form (admin_editcemetery.php).

This program finds all Placenames (in all trees) that match the querystring parameter $searchkey.
Each matching Placename is returned in an HTML table, along with a Select button, the
Tree, Latitude, Longitude, and Zoom level from the Places, and, optionally, the number
of Burial events that use that Placename. (It is optional because, in large trees, the
burials could take too long to count.)

The results table will have a heading row that holds three checkboxes that represent the
data elements that can be extracted from a Placename record. Those three data elements
(which map from and to 'fields', but aren't 'fields') are:
 - Cemetery - The first comma-part of each matching placename
 - Location - The remaining comma-parts of each matching placename (as one string)
 - Geocodes - Latitude, Longitude, and Zoom level.
The checkboxes get their initial values from the $placeElementsToCopy querystring parameter.

The data elements are stored in <span> elements in the results table, with ID's that allow
the elements from the selected HTML table row to be copied into the Cemetery edit form.

The calling program will display the HTML table, and allow the user to select one Placename.
The checkboxes in the table heading indicate whether the corresponding data elements are to be copied to the Cemetery form when a Placename is selected.  Data values whose checkboxes have been checked are shaded in grey, and the shading is added or removed when the checkeboxes are checked or unchecked)

Input query-string parameters:
 $searchkey = The search key is treated differently, depending on $lookuptype
 $lookuptype = 'contains', 'startswith', or 'each';
    If lookuptype='each', then the searchkey is broken into its comma-parts, and
    each placename in the database is searched for each of the comma-parts.
 $countBurials = binary flag
 $copyCemname = binary flag
 $copyLocation = binary flag
 $copyGeocodes = binary flag
*/

$admin_cemetery_edit_cust_text=1; #Allows strings to be loaded from cust_text.php
$tngModNames['Admin Cemetery Edit']['rrcemeteriessearch_ajx.php'] = '9'; #"Register" the mod

include("begin.php");
include("adminlib.php");
$textpart = "cemeteries";
include("$mylanguage/admintext.php");

@set_time_limit(0);
session_write_close(); # Disable session writes so that other sessions can start.

header("Content-type:text/html; charset=" . $session_charset);

if (!$searchkey) {
echo $admtext['rrace-nokey'];
	exit;
}


#Count place trees
if ($tngconfig['places1tree']) $treecount=1;
else {
	$query = "SELECT count(*) AS treecount FROM $trees_table";
	$treeresult = tng_query($query);
	$treerow = tng_fetch_assoc($treeresult);
	$treecount = $treerow['treecount'];
}

# Build the WHERE clause of the SQL statement based in the lookup type.
switch ($lookuptype) {
	case 'contains':
		$sqlwhere = "p.place LIKE \"%$searchkey%\"";
		break;
	case 'each': # Separate the comma-pieces, and search for ALL of them
		#We can just use comma as a separator and trim each comma-piece in case
		#there are spaces after the commas
		$sqlwhere='';
		$commapieces = array_map('trim', explode(',', $searchkey));
		foreach ($commapieces AS $value)
			$sqlwhere .= ($sqlwhere ? ' AND ' : '') . "p.place LIKE \"%$value%\"";
		break;
	default: #'startswith' or anything else,
		$sqlwhere = "p.place LIKE \"$searchkey%\"";
} #end switch

# The $countBurials flag affects a computed field in the field list, and a LEFT JOIN
if ($countBurials) {
	$sqlCount = ", COUNT(people.burialplace) AS burials";
	$sqlJoin = "LEFT JOIN $people_table people ON people.burialplace=p.place AND people.gedcom=p.gedcom";
} else $sqlCount = $sqlJoin = '';

# Do a query against matching places, and count the number of primary burial events at each place.
# There are 2 SQL statements; one for multiple place trees, and one for a single place tree.
if ($treecount>1)
	$query = "SELECT p.place, p.latitude, p.longitude, p.gedcom, p.zoom, t.treename$sqlCount
		FROM $places_table p
		LEFT JOIN $trees_table t ON t.gedcom=p.gedcom $sqlJoin
		WHERE $sqlwhere
		GROUP BY p.place, t.treename
		ORDER BY p.place, t.treename";
else
	$query = "SELECT p.place, p.latitude, p.longitude, p.gedcom, p.zoom$sqlCount
		FROM $places_table p $sqlJoin
		WHERE $sqlwhere
		GROUP BY p.place
		ORDER BY p.place";
$placeresult= tng_query($query);
$numplacerows = tng_num_rows( $placeresult );

if (!$numplacerows) {
	echo "{$admtext['rrace-nocems']} $searchkey"; #No matching records
	exit;
}

#Put a hidden help message at the beginning of the pop-up div.
$admtext['rrace-lookuphelp1'] = "<li>You are associating the Cemetery with a Place<i>name</i>, not with a specific place in a specific tree.
	The tree names do not affect the Associated Place value.</li>\n";
$admtext['rrace-lookuphelp2'] = "<li>When you select a Place, the full Placename will be copied to the Cemetery's Associated Placename field.</li>
<li>The checked boxes and shaded data indicate which data elements will also be copied to Cemetery fields.</li>
<li>If a location component is completely omitted
(e.g. if 'Chicago, , Illinois' is represented as 'Chicago, Illinois'),
the location components might not land in the correct location component fields.</li>
<li>A mod option controls whether the burial count for each cemetery is displayed.</li>\n";
echo "<div id='placenamehelp' class='rrresultswindow' style='display:none;'><ol>\n";
if ($treecount>1) echo "{$admtext['rrace-lookuphelp1']}\n";
echo "{$admtext['rrace-lookuphelp2']}\n";
echo "</ol></div>\n";

##### The table of matching place names
# In the heading, put the 3 checkboxes in table cells corresponding to the data elements they
# effect.  The checkboxes share an onclick handler that is defined in the calling program.
# The onclick handler adds the rraceShaded class to the corresponding data element when the checkbox
# is checked, or removes it when the checkbox is unchecked.
echo "{$admtext['rrace-selectplace']}. {$admtext['rrace-alsofill']}<br>";

#Cemetery checkbox
$checked = $cemnameclass = '';
if ($copyCemname) {
	$cemnameclass = ' rraceShaded';
	$checked=' checked';
}
echo "<input type='checkbox' id='copycemname' value='1' $checked
	onclick=\"rrSetLookupBoxShading('cemname');\"/>{$admtext['cemeteryname']}&nbsp;&nbsp;";

#Location checkbox
$checked = $locationclass = '';
if ($copyLocation) {
	$locationclass = ' rraceShaded';
	$checked=' checked';
}
echo "<input type='checkbox' id='copylocation' value='1' $checked
	onclick=\"rrSetLookupBoxShading('location');\"/>{$admtext['rrace-citycounty']}";

#Geocodes checkbox
$checked = $geocodesclass = '';
if (copyGeocodes) {
	$geocodesclass = ' rraceShaded';
	$checked=' checked';
}
echo " &nbsp; <input type='checkbox' id='copygeocodes' value='1' $checked
	onclick=\"rrSetLookupBoxShading('geocodes');\"$checked/>{$admtext['rrace-geocodes']}";

### Table column headings
echo "<table class='normal' id='rraceLookupResults'>
	<thead>
	<tr class='fieldnameback fieldname'>
		<th>&nbsp;</th>
		<th>{$admtext['place']}</th>\n";
	#We don't always include the Tree and BurialCount columns
	if ($treecount>1) {
		echo "<th class='rrTreeValue'><a href='#' class='lightlink' style='text-decoration:underline;'
			onclick=\"$('.rrTreeValue').toggle();return false;\">{$admtext['tree']}</a></th>";
		echo "<th class='rrTreeValue' style='display:none;'><a href='#' class='lightlink' style='text-decoration:underline;'
			onclick=\"$('.rrTreeValue').toggle();return false;\">{$admtext['tree']}</a></th>";
	}
	if ($countBurials) echo "<th>#</th>";
	echo "<th>{$admtext['latitude']}</th><th>{$admtext['longitude']}</th>
	</tr>
	</thead><tbody>\n";

##### Now the table body - the result rows
$i = 0;
while( $placerow = tng_fetch_assoc($placeresult)) {
	$i++;
	#Separate the place name into what should be a cemetery name and the location
	$placeparts = explode(',', $placerow['place'], 2);
	if (substr($placeparts[1],0,1) == ' ') {
		$delimiter = ', '; #comma-space;
	} else $delimiter = ','; #comma only

	#Output the results table row. The data elements that can be copied are placed in span
	#elements who id identifies the data element and the table row.
	echo "<tr style='vertical-align:top;' class='lightback'>
		<td><input type='button' name='btn$i' id='btn$i' value='{$admtext['select']}' style='font-size:85%;' onclick='rrUseThisPlace($i);' /></td>
		<td>
			<input type='hidden' id='place$i' value=\"{$placerow['place']}\"\>
			<span class='rrcemname$cemnameclass' id='cemname$i'>{$placeparts[0]}</span>$delimiter<span class='rrlocation$locationclass' id='location$i'>{$placeparts[1]}</span></td>\n";
		#Don't always display the treename
		if ($treecount>1) {
			echo "		<td class='rrTreeValue'>{$placerow['gedcom']}</td>\n";
			echo "		<td class='rrTreeValue' style='display:none;'>{$placerow['treename']}</td>\n";
		}
		#Don't always display the burial count
		if ($countBurials)
			echo "		<td>{$placerow['burials']}</td>\n";
		#The Latitude and Longitude are span elements in separate columns. The Zoom level is in a
		#hidden span element in the Longitude columns.
		echo "<td class='lightback'><span class='rrgeocodes$geocodesclass' id='latitude$i'>" . ($placerow['latitude'] ? number_format($placerow['latitude'],6) : "&nbsp;") . "</span></td>
		<td><span class='rrgeocodes$geocodesclass' id='longitude$i'>" . ($placerow['longitude'] ? number_format($placerow['longitude'],6) : "&nbsp;") . "</span>
		<span id='zoom$i' style='display:none;'>{$placerow['zoom']}</span></td>
		</tr>\n";
}
echo "  </tbody></table>\n";

#Possible footnote about the burials column, since the heading for that column is just "#"
if ($countBurials)
	echo $admtext['rrace-burialsnote'] . "\n";

### Done
?>
