<?php
##### rrinnermodmenu1_php.php - a "protected" Include file installed by Robin Richmond's mods
# that add an "Inner Mod Menu" to an Inner Menu.
/*
The '1' in the Include filename and in the function defined in this file are version #s.

The "Inner Mod Menu" is a right-floated drop-down menu in the standard TNG "Inner Menu".
It contains links that describe what a particular mod does to the TNG program, and is
intended for TNG administrators, not end-users.

The function rrBuildInnerModMenu{v#} defines the HTML code for Inner Mod Menu links.
Since a program can be modified by more than one mod, more than one call to the
function can be inserted into a program, and the Inner Mod Menu can contain links
for more than one mod.

What's in the Inner Menu Mod (for a given mod)
The mod name, as a heading, with a Wiki logo link to the mods's Wiki article.
Optionally, links to:
- The "Mod Options" section of the mod's Wiki Article,
- The block of fields that update this mod's options (in an Admin>>Setup program), and/or
- A TNG Help page - generally when the help page describes changes made by the mod
*/
#############################################################
/* rrBuildInnerModMenu1 - Function to build an Inner Mod Menu
Input:
  $modname - (I'll make you guess)
  $haswikioptions - Truthy if there is a "Mod Options" section in the mods Wiki article.
  $configprogram - The Admin>>Setup program through which this mod's options can be
     edited. If non-empty, the function creates a link to the mod's options's fields.
  $subform - The subform where this mods options are placed in the configuration program.
       Can be empty, and if $configprogram is empty, this option is ignored.
  $helppage - The filename of the TNG help page that describes the mod's changes, possibly
      with an anchor that specifies the location of the relevant text within the help file.
Return value:
  The HTML code for the heading and links specified by this call.

Note that the hyperlink text that this function generates ("Mod Options Help", 
"Change Mod Options", and "What has Changed"), is hard-coded, since we don't
know which mod generated it, and I didn't want to add the language strings to
 every mod that generates an InnerModMenu.
*/
#############################################################
#############################################################
function rrBuildInnerModMenu1($modname, $haswikioptions=0, $configprogram='', $subform='', $helppage='') {
	global $admtext;
	#Always use the mod name as a heading. Define it as a link so that it has the right styling.
	#on the same line as the heading, add a Wiki icon that pops up the mod's Wiki article.
	$html = "<div class='rrInnerModMenu' style='display:none;'>";
	$html .= "<span class='nw rrInnerModNotLink'><b style='font-size:110%;'>$modname</b>&nbsp;";
	$html .= "&nbsp;&nbsp;<img src='img/rrmodadmin_wikilogo.png' class='rrInnerModWiki' onclick=\"return rrInnerModOpenWikiPage('$modname');\"></span><br>";

	if ($haswikioptions)
		#Add a link that pops up the mod's wiki article, positioned to a Mod Options section.
		$html .= "&nbsp;&nbsp;&nbsp;<a href='#' class='nw' onclick=\"return rrInnerModOpenWikiPage('$modname','Mod_Options');\"><b>Mod Options Help</b></a><br>";

	if ($configprogram) {
		#Add a link to the mod options editor
		if (substr($configprogram,0,6) != 'admin_') $configprogram = "admin_$configprogram";
		if (substr($configprogram, -4) != '.php') $configprogram .= '.php';
		$modid = str_replace(' ', '', $modname);
		$html .= "&nbsp;&nbsp;&nbsp;<a href='#' onclick=\"return rrInnerModOpenConfigPage('$configprogram', '$subform', '$modid');\" class='nw'><b>Change Mod Options</b></a><br>";
	}

	if ($helppage) {
		#Define a link to the relevant help file.
		$html .= "&nbsp;&nbsp;&nbsp;<a href='#' onclick=\"return openHelp('$helppage');\"><b>What has changed</b></a><br>";
	}
	return $html . "</div>";
} #end function rrBuildInnerModMenu1
?>
